@@ -8,9 +8,18 @@ import (
 	"github.com/go-redis/redis/internal/proto"
 )
 
-func IsRetryableError(err error, retryNetError bool) bool {
-	if IsNetworkError(err) {
-		return retryNetError
+func IsRetryableError(err error, retryTimeout bool) bool {
+	if err == nil {
+		return false
+	}
+	if err == io.EOF {
+		return true
+	}
+	if netErr, ok := err.(net.Error); ok {
+		if netErr.Timeout() {
+			return retryTimeout
+		}
+		return true
 	}
 	s := err.Error()
 	if s == "ERR max number of clients reached" {
@@ -19,6 +28,9 @@ func IsRetryableError(err error, retryNetError bool) bool {
 	if strings.HasPrefix(s, "LOADING ") {
 		return true
 	}
+	if strings.HasPrefix(s, "READONLY ") {
+		return true
+	}
 	if strings.HasPrefix(s, "CLUSTERDOWN ") {
 		return true
 	}
@@ -30,24 +42,12 @@ func IsRedisError(err error) bool {
 	return ok
 }
 
-func IsNetworkError(err error) bool {
-	if err == io.EOF {
-		return true
-	}
-	_, ok := err.(net.Error)
-	return ok
-}
-
-func IsReadOnlyError(err error) bool {
-	return strings.HasPrefix(err.Error(), "READONLY ")
-}
-
 func IsBadConn(err error, allowTimeout bool) bool {
 	if err == nil {
 		return false
 	}
 	if IsRedisError(err) {
-		return false
+		return strings.HasPrefix(err.Error(), "READONLY ")
 	}
 	if allowTimeout {
 		if netErr, ok := err.(net.Error); ok && netErr.Timeout() {
